aboutsummaryrefslogtreecommitdiff
path: root/.run
diff options
context:
space:
mode:
author魏曹先生 <1992414357@qq.com>2026-07-17 11:15:02 +0800
committer魏曹先生 <1992414357@qq.com>2026-07-17 11:15:02 +0800
commit4f241913e4c153650eb2a8834a88ea6f44c09d92 (patch)
treeedee9972f9e988fe32465b153b3b9a3459c82b0d /.run
parent4d2d34476507c1fbdd8d7415d14e84d720a76a93 (diff)
feat(dependency_order): include crates starting with "arg" in filter
Extend the workspace member filter to also match crates prefixed with "arg" in addition to "mingling"
Diffstat (limited to '.run')
-rw-r--r--.run/src/dependency_order.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/.run/src/dependency_order.rs b/.run/src/dependency_order.rs
index 7235f12..99317ae 100644
--- a/.run/src/dependency_order.rs
+++ b/.run/src/dependency_order.rs
@@ -146,10 +146,10 @@ pub fn display_dependency_order() -> Vec<PathBuf> {
// Read workspace members from root Cargo.toml
let members = get_workspace_members(&workspace_root);
// Filter to crates starting with "mingling"
let mingling_crates: HashSet<String> = members
.into_iter()
- .filter(|m| m.starts_with("mingling"))
+ .filter(|m| m.starts_with("mingling") || m.starts_with("arg"))
.collect();
if mingling_crates.is_empty() {
@@ -146,10 +146,10 @@ pub fn display_dependency_order() -> Vec<PathBuf> {
// Read workspace members from root Cargo.toml
let members = get_workspace_members(&workspace_root);
- // Filter to crates starting with "mingling"
+ // Filter to crates starting with "mingling" or "arg"
let mingling_crates: HashSet<String> = members
.into_iter()